@@ -1,7 +1,7 @@
-from is_core.generic_views.form_views import DetailModelFormView
+from is_core.generic_views.detail_views import DjangoDetailFormView
 
 
-class UserDetailView(DetailModelFormView):
+class UserDetailView(DjangoDetailFormView):
 
     def leading_issue_name(self, obj):
         return obj.leading_issue.name if hasattr(obj, 'leading_issue') else 'No leading issue'
